Contributing to Qililab
=======================

This contributor's guide contains information on how to contribute to the `Qililab` codebase.

The sections below are aimed towards developers and cover how to install
`Qililab` and its dependencies in development mode, run and add tests, write
documentation, as well as general best practices and an architectural overview
of `Qililab`.

.. warning::

   This project is primarily intended for reference purposes, and we do not actively accept
   or manage external contributions, including pull requests and issue reports. Our development team maintains this codebase for internal use and does not have the capacity to review or merge contributions from the community.

.. grid:: 2

   .. grid-item-card:: Development Installation
      :link: dev_installation.html
      :text-align: center

      Installation of Qililab's source code using development mode.
